@@ -2,7 +2,7 @@ import abc
 import json
 import logging
 import os
-from typing import Dict, Any, Callable, Tuple, List, Generator, Union
+from typing import Any, Callable, Generator
 
 from google import auth
 from google.auth import iam
@@ -11,9 +11,9 @@ from google.auth.impersonated_credentials import Credentials as ImpersonatedCred
 from google.auth.transport import requests
 from google.oauth2.service_account import Credentials as ServiceAccountCredentials
 from google.protobuf.duration_pb2 import Duration  # pylint: disable=no-name-in-module
-from googleapiclient.discovery import build, Resource
+from googleapiclient.discovery import Resource, build
 from googleapiclient.errors import HttpError
-from requests import Response, HTTPError
+from requests import HTTPError, Response
 
 from gcp_pilot import exceptions
 
@@ -23,10 +23,10 @@ DEFAULT_SERVICE_ACCOUNT = os.environ.get("GCP_SERVICE_ACCOUNT", None)
 
 TOKEN_URI = "https://accounts.google.com/o/oauth2/token"
 
-PolicyType = Dict[str, Any]
-AuthType = Tuple[Credentials, str]
-ImpersonatedAuthType = Tuple[ImpersonatedCredentials, str]
-ResourceType = Dict[str, Any]
+PolicyType = dict[str, Any]
+AuthType = tuple[Credentials, str]
+ImpersonatedAuthType = tuple[ImpersonatedCredentials, str]
+ResourceType = dict[str, Any]
 
 logger = logging.getLogger()
 
@@ -40,19 +40,19 @@ MINIMAL_SCOPES = [
 
 class GoogleCloudPilotAPI(abc.ABC):
     _client_class = None
-    _scopes: List[str] = []
-    _iam_roles: List[str] = []
-    _cached_credentials: AuthType = None
+    _scopes: list[str] = []
+    _iam_roles: list[str] = []
+    _cached_credentials: AuthType | None = None
     _service_name = None
     _google_managed_service = False  # Service agent requires impersonation
 
     def __init__(
         self,
-        subject: str = None,
-        location: str = None,
-        project_id: str = None,
-        impersonate_account: str = None,
-        credentials: Credentials = None,
+        subject: str | None = None,
+        location: str | None = None,
+        project_id: str | None = None,
+        impersonate_account: str | None = None,
+        credentials: Credentials | None = None,
         **kwargs,
     ):
         if credentials:
@@ -60,18 +60,18 @@ class GoogleCloudPilotAPI(abc.ABC):
         else:
             self.credentials, credential_project_id = self._set_credentials(
                 subject=subject,
-                impersonate_account=impersonate_account or DEFAULT_SERVICE_ACCOUNT,
+                impersonate_account=impersonate_account,
             )
         self.project_id = self._set_project_id(project_id=project_id, credential_project_id=credential_project_id)
 
         self.client = self._build_client(**kwargs)
 
-        self.location = self._set_location(location=location)
+        self._location = location or DEFAULT_LOCATION
 
     def _get_client_extra_kwargs(self):
         return {}
 
-    def _build_client(self, **kwargs) -> Union[Resource, _client_class]:
+    def _build_client(self, **kwargs) -> Resource | _client_class:
         kwargs.update(self._get_client_extra_kwargs())
 
         return (self._client_class or build)(credentials=self.credentials, **kwargs)
@@ -79,15 +79,21 @@ class GoogleCloudPilotAPI(abc.ABC):
     def _set_project_id(self, project_id: str, credential_project_id: str) -> str:
         return project_id or DEFAULT_PROJECT or credential_project_id
 
-    def _set_location(self, location: str = None) -> str:
+    def _set_location(self, location: str | None = None) -> str:
         return location or DEFAULT_LOCATION or self._get_project_default_location()
 
+    @property
+    def location(self):
+        if not self._location:
+            self._location = self._get_project_default_location()
+        return self._location
+
     @classmethod
     def _impersonate_account(
         cls,
         credentials: Credentials,
         service_account: str,
-        scopes: List[str],
+        scopes: list[str],
     ) -> ImpersonatedAuthType:
         credentials = ImpersonatedCredentials(
             source_credentials=credentials,
@@ -108,7 +114,7 @@ class GoogleCloudPilotAPI(abc.ABC):
         cls,
         credentials: Credentials,
         subject: str,
-        scopes: List[str],
+        scopes: list[str],
     ) -> ServiceAccountCredentials:
         try:
             admin_credentials = credentials.with_subject(subject).with_scopes(scopes)
@@ -138,7 +144,7 @@ class GoogleCloudPilotAPI(abc.ABC):
         return admin_credentials
 
     @classmethod
-    def _set_credentials(cls, subject: str = None, impersonate_account: str = None) -> AuthType:
+    def _set_credentials(cls, subject: str | None = None, impersonate_account: str | None = None) -> AuthType:
         # Speed up consecutive authentications
         # TODO: check if this does not break multiple client usage
         all_scopes = MINIMAL_SCOPES + cls._scopes
@@ -148,7 +154,11 @@ class GoogleCloudPilotAPI(abc.ABC):
         else:
             credentials, project_id = cls._cached_credentials
 
-        if impersonate_account and getattr(credentials, "service_account_email") != impersonate_account:
+        current_account = getattr(credentials, "service_account_email", None)
+        if current_account == "default":  # common when inside GCP
+            current_account = DEFAULT_SERVICE_ACCOUNT
+
+        if impersonate_account and impersonate_account != current_account:
             credentials, impersonated_project_id = cls._impersonate_account(
                 credentials=credentials,
                 service_account=impersonate_account,
@@ -161,19 +171,19 @@ class GoogleCloudPilotAPI(abc.ABC):
 
         return credentials, (project_id or getattr(credentials, "project_id", None))
 
-    def get_oidc_token(self, audience: str = None) -> Dict[str, Dict[str, str]]:
+    def get_oidc_token(self, audience: str | None = None) -> dict[str, dict[str, str]]:
         oidc_token = {"service_account_email": self.credentials.service_account_email}
         if audience:
             # TODO: make sure that, if URL, the query params are removed
             oidc_token["audience"] = audience
         return {"oidc_token": oidc_token}
 
-    async def set_up_permissions(self, email: str, project_id: str = None) -> None:
+    def set_up_permissions(self, email: str, project_id: str | None = None) -> None:
         from gcp_pilot.resource import ResourceManager, ServiceAgent  # pylint: disable=import-outside-toplevel
 
         rm = ResourceManager()  # pylint: disable=invalid-name
         for role in self._iam_roles:
-            await rm.add_member(
+            rm.add_member(
                 email=email,
                 role=role,
                 project_id=project_id or self.project_id,
@@ -185,7 +195,7 @@ class GoogleCloudPilotAPI(abc.ABC):
                 project_id=self.project_id,
             )
 
-            await ResourceManager().allow_impersonation(
+            ResourceManager().allow_impersonation(
                 email=email,
                 project_id=project_id,
             )
@@ -200,13 +210,13 @@ class GoogleCloudPilotAPI(abc.ABC):
         return Duration(seconds=seconds) if seconds else None
 
     @classmethod
-    def build_from(cls, client: "GoogleCloudPilotAPI", project_id: str = None):
+    def build_from(cls, client: "GoogleCloudPilotAPI", project_id: str | None = None):
         return cls(
             credentials=client.credentials,
             project_id=project_id or client.project_id,
         )
 
-    def _get_project_default_location(self, project_id: str = None) -> Union[str, None]:
+    def _get_project_default_location(self, project_id: str | None = None) -> str | None:
         location = _CACHED_LOCATIONS.get(project_id or self.project_id, None)
         if location:
             return location
@@ -219,10 +229,10 @@ class GoogleCloudPilotAPI(abc.ABC):
         except exceptions.NotFound:
             return None
 
-    def _project_path(self, project_id: str = None) -> str:
+    def _project_path(self, project_id: str | None = None) -> str:
         return f"projects/{project_id or self.project_id}"
 
-    def _location_path(self, project_id: str = None, location: str = None) -> str:
+    def _location_path(self, project_id: str | None = None, location: str | None = None) -> str:
         project_path = self._project_path(project_id=project_id)
         return f"{project_path}/locations/{location or self.location}"
 
@@ -244,13 +254,13 @@ class AccountManagerMixin:
         prefix = "serviceAccount" if is_service_account else "member"
         return f"{prefix}:{email}"
 
-    def _make_public(self, role: str, policy: Dict) -> Dict:
+    def _make_public(self, role: str, policy: dict) -> dict:
         return self._bind_email_to_policy(email="allUsers", role=role, policy=policy)
 
-    def _make_private(self, role: str, policy: Dict) -> Dict:
+    def _make_private(self, role: str, policy: dict) -> dict:
         return self._unbind_email_from_policy(email="allUsers", role=role, policy=policy)
 
-    def _bind_email_to_policy(self, email: str, role: str, policy: Dict) -> Dict:
+    def _bind_email_to_policy(self, email: str, role: str, policy: dict) -> dict:
         new_policy = policy.copy()
 
         role_id = role if (role.startswith("organizations/") or role.startswith("roles/")) else f"roles/{role}"
@@ -273,7 +283,7 @@ class AccountManagerMixin:
             new_policy["version"] = 1  # TODO: handle version 2 and 3 as its conditional roles
         return new_policy
 
-    def _unbind_email_from_policy(self, email: str, role: str, policy: Dict):
+    def _unbind_email_from_policy(self, email: str, role: str, policy: dict):
         role_id = f"roles/{role}"
         member = self._as_member(email=email)
 
@@ -294,7 +304,7 @@ class AppEngineBasedService:
     # is created in a region and this region cannot be changed ever.
     # So these clients cannot just choose a desired region to work on, they must use the App Engine's
     # previously chosen region.
-    def _set_location(self, location: str = None):
+    def _set_location(self, location: str | None = None):
         project_location = self._get_project_default_location()
 
         explicit_location = location
@@ -373,7 +383,7 @@ class DiscoveryMixin:
         self,
         method: Callable,
         result_key: str = "items",
-        params: Dict[str, Any] = None,
+        params: dict[str, Any] | None = None,
     ) -> Generator[ResourceType, None, None]:
         results = self._execute(
             method=method,
@@ -386,9 +396,11 @@ class DiscoveryMixin:
         self,
         method: Callable,
         result_key: str = "items",
-        params: Dict[str, Any] = None,
-        order_by: str = None,
-        limit: int = None,
+        pagination_key: str = "pageToken",  # Because GCP can be weird sometimes
+        next_pagination_key: str = "nextPageToken",
+        params: dict[str, Any] | None = None,
+        order_by: str | None = None,
+        limit: int | None = None,
     ) -> Generator[ResourceType, None, None]:
         page_token = None
         params = params or {}
@@ -403,14 +415,16 @@ class DiscoveryMixin:
             params["maxResults"] = limit
 
         while True:
+            call_kwargs = params.copy()
+            if page_token:
+                call_kwargs[pagination_key] = page_token
             results = self._execute(
                 method=method,
-                **params,
-                pageToken=page_token,
+                **call_kwargs,
             )
             for item in results.get(result_key, []):
                 yield item
 
-            page_token = results.get("nextPageToken")
+            page_token = results.get(next_pagination_key)
             if not page_token:
                 break
