@@ -1,10 +1,10 @@
 # More Information: <https://cloud.google.com/functions/docs/reference/rest>
-from typing import Dict, Any, Generator
+from typing import Any, Generator
 
-from gcp_pilot.base import GoogleCloudPilotAPI, DiscoveryMixin, PolicyType, AccountManagerMixin
 from gcp_pilot import exceptions
+from gcp_pilot.base import AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI, PolicyType
 
-FunctionType = Dict[str, Any]
+FunctionType = dict[str, Any]
 
 
 class CloudFunctions(DiscoveryMixin, AccountManagerMixin, GoogleCloudPilotAPI):
@@ -20,14 +20,18 @@ class CloudFunctions(DiscoveryMixin, AccountManagerMixin, GoogleCloudPilotAPI):
             **kwargs,
         )
 
-    def _parent_path(self, project_id: str = None, location: str = None) -> str:
+    def _parent_path(self, project_id: str | None = None, location: str | None = None) -> str:
         return self._location_path(project_id=project_id, location=location)
 
-    def _function_path(self, name: str, project_id: str = None, location: str = None) -> str:
+    def _function_path(self, name: str, project_id: str | None = None, location: str | None = None) -> str:
         location_path = self._location_path(project_id=project_id, location=location)
         return f"{location_path}/functions/{name}"
 
-    def get_functions(self, project_id: str = None, location: str = None) -> Generator[FunctionType, None, None]:
+    def get_functions(
+        self,
+        project_id: str | None = None,
+        location: str | None = None,
+    ) -> Generator[FunctionType, None, None]:
         params = dict(
             parent=self._parent_path(project_id=project_id, location=location),
         )
@@ -37,7 +41,7 @@ class CloudFunctions(DiscoveryMixin, AccountManagerMixin, GoogleCloudPilotAPI):
             params=params,
         )
 
-    def get_function(self, name: str, project_id: str = None, location: str = None) -> FunctionType:
+    def get_function(self, name: str, project_id: str | None = None, location: str | None = None) -> FunctionType:
         function_name = self._function_path(name=name, project_id=project_id, location=location)
         return self._execute(
             method=self.client.projects().locations().functions().get,
@@ -48,12 +52,12 @@ class CloudFunctions(DiscoveryMixin, AccountManagerMixin, GoogleCloudPilotAPI):
     def build_repo_source(
         cls,
         name,
-        branch: str = None,
-        commit: str = None,
-        tag: str = None,
-        directory: str = None,
-        project_id: str = None,
-    ) -> Dict[str, Any]:
+        branch: str | None = None,
+        commit: str | None = None,
+        tag: str | None = None,
+        directory: str | None = None,
+        project_id: str | None = None,
+    ) -> dict[str, Any]:
 
         valid_references = [ref for ref in [branch, commit, tag] if ref]
         if len(valid_references) > 1:
@@ -92,16 +96,16 @@ class CloudFunctions(DiscoveryMixin, AccountManagerMixin, GoogleCloudPilotAPI):
         runtime: str = "python39",
         timeout: int = 60,
         ram: int = 128,
-        repo_branch: str = None,
-        repo_tag: str = None,
-        repo_commit: str = None,
-        repo_directory: str = None,
-        labels: Dict[str, str] = None,
-        env_vars: Dict[str, str] = None,
-        max_instances: int = None,
-        project_id: str = None,
-        location: str = None,
-        service_account_email: str = None,
+        repo_branch: str | None = None,
+        repo_tag: str | None = None,
+        repo_commit: str | None = None,
+        repo_directory: str | None = None,
+        labels: dict[str, str] | None = None,
+        env_vars: dict[str, str] | None = None,
+        max_instances: int | None = None,
+        project_id: str | None = None,
+        location: str | None = None,
+        service_account_email: str | None = None,
         is_public: bool = False,
     ) -> FunctionType:
         repo = self.build_repo_source(
@@ -148,7 +152,7 @@ class CloudFunctions(DiscoveryMixin, AccountManagerMixin, GoogleCloudPilotAPI):
 
         return {"name": operation["metadata"]["target"]}
 
-    def get_permissions(self, name: str, project_id: str = None, location: str = None) -> PolicyType:
+    def get_permissions(self, name: str, project_id: str | None = None, location: str | None = None) -> PolicyType:
         function_name = self._function_path(name=name, project_id=project_id, location=location)
 
         return self._execute(
@@ -156,7 +160,13 @@ class CloudFunctions(DiscoveryMixin, AccountManagerMixin, GoogleCloudPilotAPI):
             resource=function_name,
         )
 
-    def set_permissions(self, name: str, is_public: bool, project_id: str = None, location: str = None) -> PolicyType:
+    def set_permissions(
+        self,
+        name: str,
+        is_public: bool,
+        project_id: str | None = None,
+        location: str | None = None,
+    ) -> PolicyType:
         policy = self.get_permissions(name=name, project_id=project_id, location=location)
         role = "roles/cloudfunctions.invoker"
         if is_public:
@@ -176,7 +186,7 @@ class CloudFunctions(DiscoveryMixin, AccountManagerMixin, GoogleCloudPilotAPI):
             body=body,
         )
 
-    def delete_function(self, name: str, project_id: str = None, location: str = None) -> FunctionType:
+    def delete_function(self, name: str, project_id: str | None = None, location: str | None = None) -> FunctionType:
         function_name = self._function_path(name=name, project_id=project_id, location=location)
         operation = self._execute(
             method=self.client.projects().locations().functions().delete,
