@@ -4,15 +4,15 @@ import sys
 from dataclasses import dataclass
 from datetime import datetime, timezone
 from enum import Enum
-from typing import Dict, Optional, Union, Iterator
-from urllib.parse import urlparse, parse_qs
+from typing import Iterator
+from urllib.parse import parse_qs, urlparse
 
 from google.auth.transport import requests
 from google.oauth2 import id_token
 from tenacity import Retrying, stop_after_attempt, wait_fixed
 
 from gcp_pilot import exceptions
-from gcp_pilot.base import GoogleCloudPilotAPI, DiscoveryMixin, ResourceType
+from gcp_pilot.base import DiscoveryMixin, GoogleCloudPilotAPI, ResourceType
 
 
 class OOBCodeType(Enum):
@@ -21,7 +21,7 @@ class OOBCodeType(Enum):
     SIGNIN = "EMAIL_SIGNIN"
 
 
-def parse_timestamp(timestamp: Union[str, int, float]) -> Optional[datetime]:
+def parse_timestamp(timestamp: str | int | float) -> datetime | None:
     if not timestamp:
         return None
     if len(str(timestamp)) > 10:
@@ -48,13 +48,13 @@ class User:
     email: str
     verified: bool
     disabled: bool
-    created_at: Optional[datetime]
-    name: str = None
-    photo_url: bool = None
-    last_login_at: Optional[datetime] = None
-    password_changed_at: Optional[datetime] = None
-    extra_attributes: Dict[str, str] = None
-    tenant_id: Optional[str] = None
+    created_at: datetime | None
+    name: str | None = None
+    photo_url: bool | None = None
+    last_login_at: datetime | None = None
+    password_changed_at: datetime | None = None
+    extra_attributes: dict[str, str] | None = None
+    tenant_id: str | None | None = None
 
     @classmethod
     def create(cls, data: ResourceType) -> "User":
@@ -76,14 +76,14 @@ class User:
 class FirebaseOAuth:
     id_token: str
     access_token: str
-    refresh_token: str = None
-    token_secret: str = None
+    refresh_token: str | None = None
+    token_secret: str | None = None
 
 
 @dataclass
 class FirebaseAuthToken:
     jwt_token: str
-    request: Optional[requests.Request] = None
+    request: requests.Request | None = None
     validate_expiration: bool = True
 
     def __post_init__(self):
@@ -100,7 +100,7 @@ class FirebaseAuthToken:
         return self._data["sign_in_method"]
 
     @property
-    def tenant_id(self) -> Optional[str]:
+    def tenant_id(self) -> str | None:
         return self._data.get("tenant_id", None)
 
     @property
@@ -145,11 +145,11 @@ class FirebaseAuthToken:
         )
 
     @property
-    def raw_user(self) -> Dict:
+    def raw_user(self) -> dict:
         return json.loads(self._data["raw_user_info"])
 
     @property
-    def event_id(self) -> Dict:
+    def event_id(self) -> dict:
         return self._data["event_id"]
 
     @property
@@ -166,7 +166,7 @@ class FirebaseAuthToken:
 class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
     _scopes = ["https://www.googleapis.com/auth/identitytoolkit"]
 
-    def __init__(self, tenant_id: str = None, **kwargs):
+    def __init__(self, tenant_id: str | None = None, **kwargs):
         super().__init__(
             serviceName="identitytoolkit",
             version="v1",
@@ -178,10 +178,10 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
 
     def find(
         self,
-        email: str = None,
-        phone_number: str = None,
-        tenant_id: str = None,
-        project_id: str = None,
+        email: str | None = None,
+        phone_number: str | None = None,
+        tenant_id: str | None = None,
+        project_id: str | None = None,
     ) -> User:
         try:
             return next(self.lookup(email=email, phone_number=phone_number, tenant_id=tenant_id, project_id=project_id))
@@ -190,10 +190,10 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
 
     def lookup(
         self,
-        email: str = None,
-        phone_number: str = None,
-        tenant_id: str = None,
-        project_id: str = None,
+        email: str | None = None,
+        phone_number: str | None = None,
+        tenant_id: str | None = None,
+        project_id: str | None = None,
     ) -> Iterator[User]:
         if not email and not phone_number:
             raise exceptions.ValidationError("Either `email` or `phone_number` must be provided")
@@ -213,7 +213,7 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
         for item in response.get("users", []):
             yield User.create(data=item)
 
-    def sign_in_with_password(self, email: str, password: str, tenant_id: str = None):
+    def sign_in_with_password(self, email: str, password: str, tenant_id: str | None = None):
         data = {
             "email": email,
             "password": password,
@@ -222,7 +222,7 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
         response = self._execute(method=self.client.accounts().signInWithPassword, body=data)
         return response
 
-    def sign_in_with_phone_number(self, phone_number: str, code: str, tenant_id: str = None):
+    def sign_in_with_phone_number(self, phone_number: str, code: str, tenant_id: str | None = None):
         data = {
             "phone_number": phone_number,
             "code": code,
@@ -231,7 +231,7 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
         response = self._execute(method=self.client.accounts().signInWithPhoneNumber, body=data)
         return response
 
-    def sign_in_with_email_link(self, email: str, code: str, tenant_id: str = None):
+    def sign_in_with_email_link(self, email: str, code: str, tenant_id: str | None = None):
         data = {
             "email": email,
             "oobCode": code,
@@ -240,15 +240,24 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
         response = self._execute(method=self.client.accounts().signInWithEmailLink, body=data)
         return response
 
+    def list_users(self, tenant_id: str = None, project_id: str | None = None):
+        params = {
+            "targetProjectId": project_id or self.project_id,
+            "tenantId": tenant_id or self.tenant_id,
+        }
+        method = self.client.projects().accounts().batchGet
+        for item in self._paginate(method=method, result_key="users", pagination_key="nextPageToken", params=params):
+            yield User.create(data=item)
+
     def generate_email_code(
         self,
         type: OOBCodeType,  # pylint: disable=redefined-builtin
         email: str,
-        ip_address: str = None,
-        project_id: str = None,
+        ip_address: str | None = None,
+        project_id: str | None = None,
         send_email: bool = False,
-        redirect_url: str = None,
-        tenant_id: str = None,
+        redirect_url: str | None = None,
+        tenant_id: str | None = None,
     ) -> ResourceType:
         data = {
             "requestType": type.value,
@@ -292,7 +301,7 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
         response = self._execute(method=self.client.accounts().resetPassword, body=data)
         return response
 
-    def delete_user(self, user_id: str, tenant_id: str = None):
+    def delete_user(self, user_id: str, tenant_id: str | None = None):
         data = {
             "localId": user_id,
             "tenantId": tenant_id or self.tenant_id,
@@ -300,7 +309,7 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
         response = self._execute(method=self.client.accounts().delete, body=data)
         return response
 
-    def disable_user(self, user_id: str, project_id: str = None, tenant_id: str = None):
+    def disable_user(self, user_id: str, project_id: str | None = None, tenant_id: str | None = None):
         data = {
             "localId": user_id,
             "disableUser": True,
@@ -310,7 +319,7 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
         response = self._execute(method=self.client.accounts().update, body=data)
         return response
 
-    def enable_user(self, user_id: str, project_id: str = None, tenant_id: str = None):
+    def enable_user(self, user_id: str, project_id: str | None = None, tenant_id: str = None):
         data = {
             "localId": user_id,
             "disableUser": False,
@@ -324,12 +333,12 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
         self,
         email: str,
         password: str,
-        phone_number: str = None,
-        name: str = None,
-        photo_url: str = None,
-        user_id: str = None,
-        project_id: str = None,
-        tenant_id: str = None,
+        phone_number: str | None = None,
+        name: str | None = None,
+        photo_url: str | None = None,
+        user_id: str | None = None,
+        project_id: str | None = None,
+        tenant_id: str | None = None,
     ):
         if phone_number and not phone_number.startswith("+"):
             phone_number = f"+{phone_number}"
@@ -349,25 +358,28 @@ class IdentityPlatform(DiscoveryMixin, GoogleCloudPilotAPI):
 
         for attempt in Retrying(stop=stop_after_attempt(3), wait=wait_fixed(1)):
             with attempt:
-                return self.find(email=email, project_id=project_id)
+                return self.find(email=email, project_id=project_id, tenant_id=tenant_id or self.tenant_id)
 
     def update(
         self,
         user_id: str,
-        email: str = None,
-        password: str = None,
-        phone_number: str = None,
-        name: str = None,
-        photo_url: str = None,
-        project_id: str = None,
-        attributes: Dict[str, str] = None,
-        tenant_id: str = None,
+        email: str | None = None,
+        password: str | None = None,
+        phone_number: str | None = None,
+        name: str | None = None,
+        photo_url: str | None = None,
+        project_id: str | None = None,
+        attributes: dict[str, str] | None = None,
+        tenant_id: str | None = None,
+        enabled: bool | None = None,
     ):
         data = {
             "localId": user_id,
             "targetProjectId": project_id or self.project_id,
             "tenantId": tenant_id or self.tenant_id,
         }
+        if enabled:
+            data["disableUser"] = not enabled
         if email:
             data["email"] = email
         if password:
