@@ -1,9 +1,9 @@
 # More Information: <https://cloud.google.com/resource-manager/reference/rest>
 
-from typing import List, Tuple, Generator
+from typing import Generator
 
 from gcp_pilot import exceptions
-from gcp_pilot.base import AccountManagerMixin, GoogleCloudPilotAPI, PolicyType, DiscoveryMixin, ResourceType
+from gcp_pilot.base import AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI, PolicyType, ResourceType
 
 
 class ResourceManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
@@ -15,14 +15,14 @@ class ResourceManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
             **kwargs,
         )
 
-    def get_policy(self, project_id: str = None, version: int = 1) -> PolicyType:
+    def get_policy(self, project_id: str | None = None, version: int = 1) -> PolicyType:
         return self._execute(
             method=self.client.projects().getIamPolicy,
             resource=project_id or self.project_id,
             body={"options": {"requestedPolicyVersion": version}},
         )
 
-    def set_policy(self, policy: PolicyType, project_id: str = None) -> PolicyType:
+    def set_policy(self, policy: PolicyType, project_id: str | None = None) -> PolicyType:
         if not policy["bindings"]:
             raise exceptions.NotAllowed("Too dangerous to set policy with empty bindings")
 
@@ -32,12 +32,12 @@ class ResourceManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
             body={"policy": policy, "updateMask": "bindings"},
         )
 
-    async def add_member(self, email: str, role: str, project_id: str = None) -> PolicyType:
+    def add_member(self, email: str, role: str, project_id: str | None = None) -> PolicyType:
         policy = self.get_policy(project_id=project_id)
         changed_policy = self._bind_email_to_policy(email=email, role=role, policy=policy)
         return self.set_policy(policy=changed_policy, project_id=project_id)
 
-    async def remove_member(self, email: str, role: str, project_id: str = None) -> PolicyType:
+    def remove_member(self, email: str, role: str, project_id: str | None = None) -> PolicyType:
         policy = self.get_policy(project_id=project_id)
         changed_policy = self._unbind_email_from_policy(email=email, role=role, policy=policy)
         return self.set_policy(policy=changed_policy, project_id=project_id)
@@ -48,8 +48,8 @@ class ResourceManager(AccountManagerMixin, DiscoveryMixin, GoogleCloudPilotAPI):
             projectId=project_id or self.project_id,
         )
 
-    async def allow_impersonation(self, email: str, project_id: str = None) -> PolicyType:
-        return await self.add_member(
+    def allow_impersonation(self, email: str, project_id: str | None = None) -> PolicyType:
+        return self.add_member(
             email=email,
             role="roles/iam.serviceAccountTokenCreator",
             project_id=project_id,
@@ -316,7 +316,7 @@ class ServiceAgent:
         return data
 
     @classmethod
-    def _find(cls, service_name: str) -> Tuple[str, str]:
+    def _find(cls, service_name: str) -> tuple[str, str]:
         candidates = [f"{service_name} {suffix}" for suffix in cls._suffixes]
 
         for candidate in candidates:
@@ -345,14 +345,14 @@ class ServiceAgent:
         return project["projectNumber"]
 
     @classmethod
-    async def restore(cls, services: List[str], project_id: str) -> None:
+    def restore(cls, services: list[str], project_id: str) -> None:
         rm = ResourceManager()  # pylint: disable=invalid-name
         for service_name in services:
             email = ServiceAgent.get_email(service_name=service_name, project_id=project_id)
             role = ServiceAgent.get_role(service_name=service_name)
             if role:
                 try:
-                    await rm.add_member(email=email, role=role)
+                    rm.add_member(email=email, role=role)
                     print(f"[O] {service_name}")
                 except exceptions.ValidationError:
                     print(f"[X] {service_name}")
@@ -363,7 +363,7 @@ class ServiceAgent:
         return f"{project_number}-compute@developer.gserviceaccount.com"
 
     @classmethod
-    def get_cloud_build_service_account(cls, project_id: str = None) -> str:
+    def get_cloud_build_service_account(cls, project_id: str | None = None) -> str:
         project_number = cls.get_project_number(project_id=project_id)
         return f"{project_number}@cloudbuild.gserviceaccount.com"
 
