@@ -1,11 +1,11 @@
 # More Information <https://cloud.google.com/scheduler/docs/reference/rest>
 import os
-from typing import Dict, Generator
+from typing import Generator
 
 from google.api_core.exceptions import NotFound
 from google.cloud import scheduler
 
-from gcp_pilot.base import GoogleCloudPilotAPI, AppEngineBasedService
+from gcp_pilot.base import AppEngineBasedService, GoogleCloudPilotAPI
 
 DEFAULT_TIMEZONE = os.environ.get("TIMEZONE", "Europe/London")  # UTC
 MAX_TIMEOUT = 30 * 60  # max allowed to HTTP endpoints is 30 minutes
@@ -19,23 +19,23 @@ class CloudScheduler(AppEngineBasedService, GoogleCloudPilotAPI):
         self.timezone = kwargs.pop("timezone", DEFAULT_TIMEZONE)
         super().__init__(**kwargs)
 
-    def _parent_path(self, project_id: str = None) -> str:
+    def _parent_path(self, project_id: str | None = None) -> str:
         return self._location_path(project_id=project_id, location=self.location)
 
-    def _job_path(self, job, project_id: str = None) -> str:
+    def _job_path(self, job, project_id: str | None = None) -> str:
         parent_name = self._parent_path(project_id=project_id)
         return f"{parent_name}/jobs/{job}"
 
-    async def create(
+    def create(
         self,
         name: str,
         url: str,
         payload: str,
         cron: str,
-        timezone: str = None,
+        timezone: str | None = None,
         method: int = DEFAULT_METHOD,
-        headers: Dict[str, str] = None,
-        project_id: str = None,
+        headers: dict[str, str] | None = None,
+        project_id: str | None = None,
         use_oidc_auth: bool = True,
         timeout_in_seconds: int = MAX_TIMEOUT,
     ) -> scheduler.Job:
@@ -58,16 +58,16 @@ class CloudScheduler(AppEngineBasedService, GoogleCloudPilotAPI):
         response = self.client.create_job(request={"parent": parent, "job": job})
         return response
 
-    async def update(
+    def update(
         self,
         name: str,
         url: str,
         payload: str,
         cron: str,
-        timezone: str = None,
+        timezone: str | None = None,
         method: int = DEFAULT_METHOD,
-        headers: Dict[str, str] = None,
-        project_id: str = None,
+        headers: dict[str, str] | None = None,
+        project_id: str | None = None,
         use_oidc_auth: bool = True,
         timeout_in_seconds: int = MAX_TIMEOUT,
     ) -> scheduler.Job:
@@ -91,39 +91,39 @@ class CloudScheduler(AppEngineBasedService, GoogleCloudPilotAPI):
         )
         return response
 
-    def list(self, prefix: str = "", project_id: str = None) -> Generator[scheduler.Job, None, None]:
+    def list(self, prefix: str = "", project_id: str | None = None) -> Generator[scheduler.Job, None, None]:
         parent = self._parent_path(project_id=project_id)
         for job in self.client.list_jobs(parent=parent):
             if job.name.split("/jobs/")[-1].startswith(prefix):
                 yield job
 
-    def get(self, name: str, project_id: str = None) -> scheduler.Job:
+    def get(self, name: str, project_id: str | None = None) -> scheduler.Job:
         job_name = self._job_path(job=name, project_id=project_id)
         return self.client.get_job(
             name=job_name,
         )
 
-    async def delete(self, name: str, project_id: str = None) -> None:
+    def delete(self, name: str, project_id: str | None = None) -> None:
         job_name = self._job_path(job=name, project_id=project_id)
         return self.client.delete_job(
             name=job_name,
         )
 
-    async def put(
+    def put(
         self,
         name: str,
         url: str,
         payload: str,
         cron: str,
-        timezone: str = None,
+        timezone: str | None = None,
         method: int = DEFAULT_METHOD,
-        headers: Dict[str, str] = None,
-        project_id: str = None,
+        headers: dict[str, str] | None = None,
+        project_id: str | None = None,
         use_oidc_auth: bool = True,
         timeout_in_seconds: int = MAX_TIMEOUT,
     ) -> scheduler.Job:
         try:
-            response = await self.update(
+            response = self.update(
                 name=name,
                 url=url,
                 payload=payload,
@@ -136,7 +136,7 @@ class CloudScheduler(AppEngineBasedService, GoogleCloudPilotAPI):
                 timeout_in_seconds=timeout_in_seconds,
             )
         except NotFound:
-            response = await self.create(
+            response = self.create(
                 name=name,
                 url=url,
                 payload=payload,
