@@ -1,25 +1,25 @@
 # More Information: https://googleapis.dev/python/storage/latest/index.html
 import io
 import os
-from typing import AsyncIterator
+from typing import Generator
 
 import requests
 from google.cloud import storage
 from google.cloud.exceptions import Conflict
-from google.cloud.storage import Bucket, Blob
+from google.cloud.storage import Blob, Bucket
 
-from gcp_pilot.base import GoogleCloudPilotAPI
 from gcp_pilot import exceptions
+from gcp_pilot.base import GoogleCloudPilotAPI
 
 
 class CloudStorage(GoogleCloudPilotAPI):
     _client_class = storage.Client
 
-    async def create_bucket(
+    def create_bucket(
         self,
         name: str,
-        region: str = None,
-        project_id: str = None,
+        region: str | None = None,
+        project_id: str | None = None,
         exists_ok: bool = True,
     ) -> Bucket:
         bucket = self.client.bucket(name)
@@ -32,23 +32,23 @@ class CloudStorage(GoogleCloudPilotAPI):
         except Conflict:
             if not exists_ok:
                 raise
-            return await self.check_bucket(name=name)
+            return self.check_bucket(name=name)
 
-    async def check_bucket(self, name: str) -> Bucket:
+    def check_bucket(self, name: str) -> Bucket:
         return self.client.get_bucket(bucket_or_name=name)
 
-    async def upload(
+    def upload(
         self,
         source_file,
         bucket_name: str,
-        target_file_name: str = None,
-        chunk_size: int = None,
-        project_id: str = None,
-        region: str = None,
+        target_file_name: str | None = None,
+        chunk_size: int | None = None,
+        project_id: str | None = None,
+        region: str | None = None,
         is_public: bool = False,
-        content_type: str = None,
+        content_type: str | None = None,
     ) -> Blob:
-        target_bucket = await self.create_bucket(name=bucket_name, project_id=project_id, region=region)
+        target_bucket = self.create_bucket(name=bucket_name, project_id=project_id, region=region)
 
         target_file_name = target_file_name or str(source_file).rsplit("/", maxsplit=1)[-1]
         blob = target_bucket.blob(target_file_name, chunk_size=chunk_size)
@@ -72,34 +72,34 @@ class CloudStorage(GoogleCloudPilotAPI):
 
         return blob
 
-    async def copy(
+    def copy(
         self,
         source_file_name,
         source_bucket_name: str,
         target_bucket_name: str,
-        target_file_name: str = None,
-        project_id: str = None,
-        region: str = None,
+        target_file_name: str | None = None,
+        project_id: str | None = None,
+        region: str | None = None,
     ) -> Blob:
-        source_bucket = await self.create_bucket(name=source_bucket_name, region=region, project_id=project_id)
+        source_bucket = self.create_bucket(name=source_bucket_name, region=region, project_id=project_id)
         source_blob = source_bucket.blob(source_file_name)
 
-        target_bucket = await self.create_bucket(name=target_bucket_name, region=region, project_id=project_id)
+        target_bucket = self.create_bucket(name=target_bucket_name, region=region, project_id=project_id)
         target_file_name = target_file_name or str(source_file_name).rsplit("/", maxsplit=1)[-1]
 
         obj = source_bucket.copy_blob(source_blob, target_bucket, target_file_name)
         return obj
 
-    async def move(
+    def move(
         self,
         source_file_name: str,
         source_bucket_name: str,
         target_bucket_name: str,
-        target_file_name: str = None,
-        project_id: str = None,
-        region: str = None,
+        target_file_name: str | None = None,
+        project_id: str | None = None,
+        region: str | None = None,
     ) -> Blob:
-        data = await self.copy(
+        data = self.copy(
             source_file_name=source_file_name,
             source_bucket_name=source_bucket_name,
             target_file_name=target_file_name,
@@ -107,15 +107,15 @@ class CloudStorage(GoogleCloudPilotAPI):
             project_id=project_id,
             region=region,
         )
-        await self.delete(file_name=source_file_name, bucket_name=source_bucket_name)
+        self.delete(file_name=source_file_name, bucket_name=source_bucket_name)
         return data
 
-    async def delete(self, file_name: str, bucket_name: str = None) -> None:
-        bucket = await self.check_bucket(name=bucket_name)
+    def delete(self, file_name: str, bucket_name: str | None = None) -> None:
+        bucket = self.check_bucket(name=bucket_name)
         blob = bucket.blob(file_name)
         return blob.delete()
 
-    async def list_files(self, bucket_name: str, prefix: str = None) -> AsyncIterator[Blob]:
+    def list_files(self, bucket_name: str, prefix: str | None = None) -> Generator[Blob, None, None]:
         blobs = self.client.list_blobs(
             bucket_name,
             prefix=prefix,
@@ -134,7 +134,7 @@ class CloudStorage(GoogleCloudPilotAPI):
         return blob
 
     def _download(self, url: str) -> io.BytesIO:
-        response = requests.get(url, stream=True)
+        response = requests.get(url, stream=True, timeout=15)
         file = io.BytesIO()
         file.write(response.content)
         file.seek(0)
